library(MuMIn)
library(arm)
library(foreign)
library(MASS)
library(ordinal)

st.err <- function(x, na.rm=FALSE) {
     if(na.rm==TRUE) x <- na.omit(x)
     sd(x)/sqrt(length(x))
     }


################################################################
import data
################################################################


data<-read.csv("eyepower.csv", header=T)
names(data)


################################################################
prepare variables
################################################################
eyes<-ifelse(data$Donation_Amount==0,1,
ifelse(data$Donation_Amount<1,2,3))


eyes_f<-factor(eyes, ordered=T)

Eyes<-ifelse(data$Image_Type_Condition=="Eyes",1,0)
Power<-(data$Power=="Low",1,0)


#clm investigating terms that affect donation amount where 1 = donated £0, 2 = donated £0.01-1.00 and 3 = donated > 1.0

global.model<-clm(eyes_f~
			
			Eyes+
			Power+
			Eyes:Power, na.action=na.fail)
			
model.set<-dredge(global.model, REML=FALSE)
top.models<-get.models(model.set, subset=delta<2)
a<-model.avg(top.models, adjusted=FALSE, revised.var=TRUE)
summary(a)
confint(a, full=T)
convergence(global.model)


#binomial glm as above but where response term = 1 if donated something and = 0 if donated nothing


global.model<-glm(Donation_Propensity~
			
			Eyes+
			Power+
			Eyes:Power, family = binomial, data=data, na.action=na.fail)
			
model.set<-dredge(global.model, REML=FALSE)
top.models<-get.models(model.set, subset=delta<2)
a<-model.avg(top.models, adjusted=FALSE, revised.var=TRUE)
summary(a)
confint(a, full=T)


#Secondary pre-registered analyses

#Is watching eye effect moderated by social attentiveness?

noticed<-data$Social_Attentiveness
cNoticed<-(noticed-mean(noticed))


global.model<-clm(eyes_f~
			
			Eyes+
			Power+
			Eyes:Power+
			cNoticed+
			cNoticed:Power:Eyes, na.action=na.fail)
			
model.set<-dredge(global.model, REML=FALSE)
top.models<-get.models(model.set, subset=delta<2)
a<-model.avg(top.models, adjusted=FALSE, revised.var=TRUE)
summary(a)
confint(a, full=T)
convergence(global.model)

global.model<-glm(Donation_Propensity~
			
			Eyes+
			Power+
			Eyes:Power+
			cNoticed+
			cNoticed:Power:Eyes, family = binomial, data=data, na.action=na.fail)
			
model.set<-dredge(global.model, REML=FALSE)
top.models<-get.models(model.set, subset=delta<2)
a<-model.avg(top.models, adjusted=FALSE, revised.var=TRUE)
summary(a)
confint(a, full=T)

#power manipulation check

data$power<-(data$Manipulation_Check1)+(data$Manipulation_Check2)

highpower<-subset(data, Power_Condition==1)
lowpower<-subset(data, Power_Condition==0)

wilcox.test(highpower$power, lowpower$power)

